@@ -21,7 +21,6 @@ typedef struct cleri_node_s cleri_node_t;
 
 /* private functions */
 cleri_node_t * cleri__node_new(cleri_t * cl_obj, const char * str, size_t len);
-void cleri__node_free(cleri_node_t * node);
 
 /* private use as empty node */
 extern cleri_node_t * CLERI_EMPTY_NODE;
@@ -38,7 +37,8 @@ struct cleri_node_s
 
     /* private */
     size_t ref;
-    int64_t result;     /* DEPRECATED */
 };
 
+
+
 #endif /* CLERI_NODE_H_ */
\ No newline at end of file
