@@ -1,19 +1,11 @@
 /*
- * ref.c - cleri ref element
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2017, Transceptor Technology
- *
- * changes
- *  - initial version, 20-06-2017
- *
+ * ref.c - cleri ref element.
  */
 #include <stdlib.h>
 #include <assert.h>
 #include <cleri/ref.h>
 
-static void REF_free(cleri_t * cl_object);
+static void ref__free(cleri_t * cl_object);
 
 /*
  * Returns NULL in case an error has occurred.
@@ -23,7 +15,7 @@ cleri_t * cleri_ref(void)
     cleri_t * cl_object = cleri_new(
             0,
             CLERI_TP_REF,
-            &REF_free,
+            &ref__free,
             NULL);
 
     return cl_object;
@@ -55,7 +47,7 @@ void cleri_ref_set(cleri_t * ref, cleri_t * cl_obj)
 /*
  * Destroy ref object. (only used when ref is not set)
  */
-static void REF_free(cleri_t * cl_object __attribute__((unused)))
+static void ref__free(cleri_t * cl_object __attribute__((unused)))
 {
     /* nothing todo */
 }
