@@ -29,7 +29,7 @@ static char * parse_str(cleri_parse_t * pr, cleri_translate_t * translate)
 
 #define _assert_is_valid(__grammar, __str) \
 { \
-    cleri_parse_t * __pr = cleri_parse(__grammar, __str); \
+    cleri_parse_t * __pr = cleri_parse2(__grammar, __str, 0); \
     _assert (__pr); \
     _assert (__pr->is_valid); \
     cleri_parse_free(__pr); \
@@ -45,7 +45,18 @@ static char * parse_str(cleri_parse_t * pr, cleri_translate_t * translate)
 
 #define _assert_parse_str(__grammar, __str, __expect, __translate) \
 { \
-    cleri_parse_t * __pr = cleri_parse(__grammar, __str); \
+    cleri_parse_t * __pr = cleri_parse2(__grammar, __str, 0); \
+    char * __s = parse_str(__pr, __translate); \
+    _assert (__s); \
+    if (strcmp(__s, __expect) != 0) printf("\n\ngot: `%s`\n", __s); \
+    _assert (strcmp(__s, __expect) == 0); \
+    free(__s); \
+    if (__pr) cleri_parse_free(__pr); \
+}
+
+#define _assert_parse_str2(__grammar, __str, __expect, __translate) \
+{ \
+    cleri_parse_t * __pr = cleri_parse2(__grammar, __str, 1); \
     char * __s = parse_str(__pr, __translate); \
     _assert (__s); \
     if (strcmp(__s, __expect) != 0) printf("\n\ngot: `%s`\n", __s); \
